---
title: "Acquérir un certificat SSL et passer son site en https"
date: "2018-04-10"
categories: 
  - "sites-web"
---

Vous pouvez acquérir un certificat SSL chez Ouvaton. C'est même automatique !

<!--more-->

### C’est quoi un certificat SSL ?

Concrètement, l’acquisition d’un certificat SSL (on parle de certificat SSL même si c’est aujourd’hui le protocole TLS qui est utilisé) pour votre site va permettre à vos visiteurs d’utiliser [HTTPS](https://fr.wikipedia.org/wiki/HyperText_Transfer_Protocol_Secure) pour y naviguer, et donc rendre votre site accessible à l’adresse https://site.tld.

![](images/ssl-visuel-eed60.png)

Un [certificat SSL/TLS](https://fr.wikipedia.org/wiki/Transport_Layer_Security) permet de garantir l’identité de votre site ainsi que la confidentialité et l’intégrité des données échangées par les visiteurs et votre site.

Il permet également d’améliorer le classement de vos sites dans les résultats des principaux moteurs de recherche, c’est un avantage pour le référencement.

### Let’s Encrypt

Nous proposons des certificats [Let’s Encrypt](https://fr.wikipedia.org/wiki/Let%27s_Encrypt) sur notre plateforme. Ces certificats sont gratuits, et permettent de sécuriser une seul adresse. Mais vous pouvez en avoir plusieurs : un pour chacun de vos espaces web.

Lors de la création d’un espace web sous un nom de domaine propre, un certificat sera automatiquement créé et installé **au plus tard 24 heures après la création de l'espace web**. Votre nouveau site sera donc disponible en HTTPS. :-)

IMPORTANT

- il faut impérativement que les URLs redirigent bien vers Ouvaton pour que la génération du certificat fonctionne
- il faut impérativement qu'un enregistrement DNS "www" de type CNAME existe et pointe sur votre nom de domaine. _Exemple : votre site s'appelle "monsite.fr", vous devez avoir (chez ouvaton ou sur le site où vous avez acheté votre domaine) une ligne_ ![](images/dns-letsencrypt-300x25.png) _Le **"·"** à la fin du nom de votre site est impératif._

Pour les sites en \*.ouvaton.org, un certificat d’Ouvaton les couvre automatiquement, ces sites sont donc aussi accessibles en HTTPS, immédiatement après la création de l'espace web.

### Et les certificats payants ?

Nous vous proposons deux types de certificat payants :

1. **le certificat pour un domaine unique**, comme www.votredomaine.tld ou blog.votredomaine.tld.  
    Notez que si votre certificat pour un domaine unique porte sur www.votredomaine.tld, l’accès à votre site via les adresses et sera sécurisé.

1. **le certificat wildcard**, qui couvre tous les sous-domaines du nom de domaine choisi.  
    Par exemple un certificat wildcard pour le domaine \*.votredomaine.tld sera valable aussi bien pour que pour ou encore .

Il existe un troisième type de certificat, le multi-domaine, que nous ne proposons pas.

Une interface sommaire pour visualiser vos certificats acquis chez Ouvaton est en cours de développement. Elle vous permettra de connaître pour chaque certificat le domaine concerné, et les dates de création et d’expiration.

Nous vendons actuellement le certificat pour un domaine unique **15 € HT / an**, et le certificat wildcard pour **80 € HT / an**.  
Dans les deux cas, l’installation est comprise.

Pour acheter un tel certificat, il faut simplement en faire la demande par le biais d’[un ticket d’assistance](https://ouvaton.coop/Assistance-par-tickets).

### Et si je désire prendre un certificat chez un autre prestataire ou que je dispose déjà d’un certificat ?

Vous pouvez sans problème acquérir votre certificat chez un prestataire de votre choix. Dans ce cas, une fois votre certificat reçu, vous devez nous le transmettre, toujours via un ticket d’assistance, pour que nous procédions à son installation sur notre plateforme.  
L’installation, qui demande rarement plus de 24 heures, est gratuite.

### Comment forcer l’utilisation de https?

Vous pouvez ajouter les lignes suivantes à votre fichier .htaccess pour forcer l'usage du HTTPS et supprimer le www. devant votre nom de domaine :

`RewriteEngine on`

`# Redirection du www vers non-www en HTTPS` `RewriteCond %{HTTP_HOST} ^www\.(.+) [NC]` `RewriteRule ^ https://%1%{REQUEST_URI} [L,R=301]`

`# Redirection vers HTTPS` `RewriteCond %{HTTPS} off` `RewriteCond %{HTTP:X-Forwarded-Proto} !https` `RewriteRule ^(.*)$ https://%{HTTP_HOST}%{REQUEST_URI} [L,R=301]`

Ou les lignes suivantes pour forcer l'usage de HTTPS et conserver le www. devant votre nom de domaine :

`RewriteEngine on`

`# Redirection du non-www vers www en HTTPS` `RewriteCond %{HTTP_HOST} !^www\.(.*)$ [NC]` `RewriteRule ^(.*)$ https://www.%{HTTP_HOST}/$1 [R=301,L]`

`# Redirection vers HTTPS` `RewriteCond %{HTTPS} off` `RewriteCond %{HTTP:X-Forwarded-Proto} !https` `RewriteRule ^(.*)$ https://%{HTTP_HOST}%{REQUEST_URI} [L,R=301]`

La conservation ou la suppression du www. devant votre nom de domaine est à votre convenance.

Si vous utilisez un CMS, pensez à modifier l’URL du site dans l’administration du CMS pour la faire commencer par https://, et veiller à ce que le www. soit présent ou pas selon l'adresse que vous voulez.

Et sous Wordpress, vous pouvez également ajouter les lignes suivantes dans le fichier wp-config.php :

`/** Force HTTPS */ define( 'FORCE_SSL_LOGIN', true ); define( 'FORCE_SSL_ADMIN', true ); if (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https') {$_SERVER['HTTPS'] = 'on';}`

Il faut ajouter ces lignes au dessus de la ligne :

`/* C'est tout, ne touchez pas à ce qui suit ! Bon blogging ! */`

Ou de la ligne si votre fichier est en anglais :

`/* That's all, stop editing! Happy publishing. */`
